import React, { useImperativeHandle, useState } from 'react';

import {
    FiveInitialize,
    ThemeProvider,
    Paper,
    Checkbox,
} from './FivePluginApi';

import { CustomFieldProps } from '../../../common';


FiveInitialize();

const CustomEditor = React.forwardRef((props: CustomFieldProps, ref) => {

    // Use the ref to hook into Five's events
    // These can be removed if they are not required
    useImperativeHandle(ref, () => ({
        onWillFullscreen,
        onFullscreen,
        onOk,
        onCancel,
    }));


    const { theme, five, onValueUpdated, value } = props;

    const [ fullscreen, setFullscreen ] = useState<boolean>(false);
    const [ valid, setValid ] = useState<boolean>(value !== "");

    const onWillFullscreen = (fullscreen: boolean): void => {
        const verb = fullscreen ? "enter" : "leave";
        console.log(`About to ${verb} fullscreen mode`);
    }

    const onFullscreen = (fullscreen: boolean): void => {
        const verb = fullscreen ? "entered" : "left";
        console.log(`Just ${verb} fullscreen mode`);
        setFullscreen(fullscreen);
    }

    const onOk = (closeDialog: () => void): void => {
        console.log("Save button clicked");

        // Do validation before saving and closing
        if(valid) {
            onValueUpdated("This is a new value!");
            closeDialog();
        } else {
            five.message("Please make sure this is valid before saving!");
        }
    }

    const onCancel = (closeDialog: () => void): void => {
        console.log("Cancel button clicked");
        closeDialog();
    }

    const onChange = (event: React.ChangeEvent<HTMLInputElement>): void => {
        setValid(event.target.checked);
    }

    const message = "Full screen is " + (fullscreen === true ? "ON" : "OFF");

    return <ThemeProvider theme={theme}>
            <Paper style={{ width: "100%", height: "100%" }}>
                <div>
                    {message}
                </div>
                <div>
                    Valid
                    <Checkbox value={valid} onChange={onChange} />
                </div>
            </Paper>
        </ThemeProvider>

});

export default CustomEditor;